---
layout: default
title: Accessing Merlin6
parent: Merlin6 User Guide
nav_order: 4
---

# Accessing Merlin6
{: .no_toc }

## Table of contents
{: .no_toc .text-delta }

1. TOC
{:toc}

---

## Requesting Merlin6 Access

PSI users with their Linux account belonging to the **svc-cluster_merlin6** group are allowed to use Merlin6. 

Registration for **Merlin6** access *must be done* through **[PSI Service Now](https://psi.service-now.com/psisp)**:

* Please open a ticket as *Incident Request*, with subject: ``[Merlin6] Access Request for user '<username>'``
* Text content example:

> Dear HelpDesk,
> 
> my name is [Name] [Surname] with PSI username [username] and I would like to request access to the Merlin6 cluster.
> 
> Please add me to the following Unix groups:
>  * 'svc-cluster_merlin6'
>
> Thanks a lot,
> <Name> <Username>

### Requesting extra Unix groups

* Some users may require to be added to some extra specific Unix groups. 
    * In example, some BIO groups may belong to a specific BIO group.
* Extra groups can be added in the *Incident Request* described in [Requesting Merlin6 Access](#Requesting-Merlin6-Access).
    * Alternatively, this step can be done later in the future on a different **[PSI Service Now](https://psi.service-now.com/psisp)** ticket.

---

## Requesting Merlin5 Access

Merlin5 computing nodes will be available for some time as a **best efford** service. If you need to use the old resources, users should belong to the **svc-cluster_merlin5** Unix Group.

Registration for **Merlin5** access *must be done* through **[PSI Service Now](https://psi.service-now.com/psisp)**

* Please open a ticket as *Incident Request*, with subject: ``[Merlin5] Access Request for user '<username>'``
* Text content example:

> Dear HelpDesk,
> 
> my name is [Name] [Surname] with PSI username [username] and I would like to request access to the old Merlin5 cluster.
> 
> Please add me to the following Unix groups:
>  * 'svc-cluster_merlin5'
>
> Thanks a lot,
> <Name> <Username>

* As described before, you can add in the *Incident Request* which extra Unix groups should be added to your user.

---

## Accessing Login/Interactive Nodes

The Merlin6 login nodes are the following:

* <tt><b>merlin-l-01.psi.ch</b></tt> - SSH Access
    * *SSH* Access
    * **Hardware description:** 32 cores (2 x 16 core Intel Xeon E5-2697A v4), 512GB RAM, 100GB ``/scratch`` on SAS disk.
* <tt><b>merlin-l-02.psi.ch</b></tt> 
    * *SSH* & **NoMachine** Access
    * **Hardware description:** 32 cores (2 x 16 core Intel Xeon E5-2697A v4), 512GB RAM, 100GB ``/scratch`` on SAS disk.
<!--* <tt><b>merlin-l-001.psi.ch</b></tt> - SSH Access -->
<!--* <tt><b>merlin-l-002.psi.ch</b></tt> - SSH Access -->

Login nodes are the official service for accessing the Merlin6 cluster. From there users can submit jobs to the Slurm batch system as well as visualize or compile their software.

### SSH Access

For interactive command access, Use SSH for accessing the login nodes. In example:

```bash
  ssh -XY [username]@merlin-l-01.psi.ch
```

X applications are supported in the login nodes and can be opened through SSH for those users who have properly configured X11 in their desktops. SSH options ``-XY`` are mandatory for that.
* Merlin6 administrators **do not offer support** with configuration for users Desktops (Windows, MAC and Linux). Hence, Merlin6 administrators **do not offer support** for X11 client setup.
* Any desktop configuration issues must be addressed through  **[PSI Service Now](https://psi.service-now.com/psisp)** as an *Incident Request*.
    * Ticket will be redirected to the corresponding Desktop support group.

### NoMachine Access

X applications are supported in the login nodes and can run through NoMachine. This service is officially supported in the Merlin6 cluster and is the official X service.
* NoMachine client installation/configuration support has to be done through **[PSI Service Now](https://psi.service-now.com/psisp)** as an *Incident Request*.
    * Ticket will be redirected to the corresponding support group.

---

## Accessing Merlin6 data

### Merlin6 directory structure

Merlin6 contain the following directories available for users:

* ``/psi/home/<username>``: private user **home** directory
* ``/data/user/<username>``: private user **home** directory
* ``/data/project/general/<projectname>``: Shared **Project** directory
* ``/scratch``: Local *scratch* disk.
* ``/shared-scratch``: Shared *scratch* disk.

#### User home directory

The user home directory can be found on login nodes and computing nodes under the ``/psi/home/<username>`` dirctory. This is the default directory users will land when login in to any Merlin6 machine.

Home directories are part of the PSI NFS Central Home storage provided by AIT, however quota administration for the Merlin6 cluster is delegated to Merlin6 administrators.

Home directory policies:
* **Per User-based Quota policy**: 
    * **Soft**: 10GB
    * **Hard**: 11GB
    * Quota can only be increased when strictly justified.
    * Check home quota with the command: ``quota -s``
* **Backup policy**:
    * **Daily snapshots for 1 week**: users can recover up to 1 week of their lost data.
    * **Snaphot location**: ``/psi/home/.snapshop/<username>``
* **Restrictions**
    * Read **[Important: Code of Conduct](## Important: Code of Conduct)** for more information about Merlin6 policies.
    * Is **forbidden** to use the home directories for IO intensive tasks (in example, IO intensive data access during job runtime).
        * Use ``/scratch``, ``/shared-scratch``, ``/data/user`` or ``/data/project`` for this purpose.

#### User data directory

The user data directory can be found on login nodes and computing nodes under the ``/data/user/<username>`` dirctory.
This storage is intended for fast IO access and keeping large amount of private data.

User data directories are part of the Merlin6 storage cluster and technology is based on GPFS.

User data directory policies:
* **Per User-based Quota policy** (as known as GPFS USR Block Limits):
    * **Soft**: 1TB
    * **Hard**: 1.074TB
    * Block quota limits can not be increased. For extra space, project must exist / be created (``/data/project/<projectname>``)
    * Check data quota with the command: ``mmlsquota -u <username> --block-size auto merlin-user``
* **Per User-based Number of Files Quota policy** (as known as GPFS USR File Limits):
    * **Soft**: 1,048,576
    * **Hard**: 1,126,400
    * File quota can be increased. For extra files, contact Merlin6 administrators.
    * Check data quota with the command: ``mmlsquota -u <username> --block-size auto merlin-user``
* **Backup policy**:
    * No backups: users are responsible for managing the backups of their data directories.
* **Restrictions**
    * Read **[Important: Code of Conduct](## Important: Code of Conduct)** for more information about Merlin6 policies.
    * Is **forbidden** to use the data directories as ``scratch`` area during a job runtime.
        * Use ``/scratch``, ``/shared-scratch`` for this purpose.
        * For temporary interactive user data (from a login node), is allowed to use it as ``scratch``-like area (in example, compiling, deploying tars, etc.)

#### Project data directory

The project data directory can be found on login nodes and computing nodes under the ``/data/user/<username>`` dirctory. 
This storage is intended for fast IO access and keeping large amount of private data, but also for sharing data amogst 
different users sharing a project. Creating a project is the way in where users can expand his storage space and will 
optimize the usage of the storage (by avoiding for instance, duplicated data for different users).
Is **highly** recommended the use of a project when multiple persons are involved in the same project managing similar/common data.
Quotas are defined in a *group* and *fileset* basis: Unix Group name must exist for a specific project or must be created for any new project.
Contact the Merlin6 administrators for more information about that.

Project data directories are part of the Merlin6 storage cluster and technology is based on GPFS.

Project data directory policies:
* **Per Group and Fileset-based Quota policy** (as known as GPFS GRP Block Limits):
    * **Soft**: 1TB
    * **Hard**: 1.074TB
    * Block quota limits can be increased on demand when strictly justified and it can be defined when a project is created. For extra space, contact Merlin6 administrators.
    * Check data quota with the command: ``mmlsquota -g <groupname> --block-size auto merlin-proj``
* **Per Group and Fileset-based Number of Files Quota policy** (as known as GPFS GRP File Limits): 
    * **Soft**: 1,048,576
    * **Hard**: 1,126,400
    * File quota can be increased on demand, and it can be defined when a new project is created. For extra files, contact Merlin6 administrators.
    * Check data quota with the command: ``mmlsquota -g <groupname> --block-size auto merlin-proj``
* **Backup policy**:
    * No backups: users are responsible for managing the backups of their data directories.
* **Restrictions**
    * Read **[Important: Code of Conduct](## Important: Code of Conduct)** for more information about Merlin6 policies.
    * Is **forbidden** to use the data directories as ``scratch`` area during a job runtime.
        * Use ``/scratch``, ``/shared-scratch`` for this purpose.
        * For temporary interactive user data (from a login node), is allowed to use it as ``scratch``-like area (in example, compiling, deploying tars, etc.)

#### Scratch directories

There are two different types of scratch disk: **local** (``/scratch``) and **shared** (``/shared-scratch``). Specific details of each type is described below.

Usually **shared** scratch will be used for those jobs which need to access to a common shared space storing temporary files, while **local** scratch should be used by those jobs which
need to store temporary files not used by jobs running on other computing nodes.

**local** scratch in computing nodes provide a huge number of IOPS thanks to the NVMe technology, while **shared** scratch, despite is also very fast, is an external storage with more latency.

By default, *always* use **local** first and only use **shared** if you specific use case needs a shared scratch area.

##### Local Scratch

Local scratch is used for creating temporary files/directories needed by running jobs. Temporary files *must be deleted at the end of the job by the user*. Remaining files will be 
deleted by the system if detected. Use always **local** by default and only use *shared* when **local** does not fit to you.

Local scratch is available on login and computing nodes, and its size depends on the host:

* **Merlin6 login nodes:** 
    * **Old login nodes:** a */scratch* partition of ~100GB is available on each login node ``merlin-l-01`` and ``merlin-l-02``. ``/scratch`` is mounted on *SAS* disks
    * **New login nodes:** a */scratch* partition of ~1.6TB is available on each login node ``merlin-l-001`` and ``merlin-l-002``. ``/scratch`` is mounted on extremely fast *NVMe Flash* disks.
* **Merlin5 computing nodes**: a */scratch* partition of ~50GB is available on each computing node. ``/scratch`` is mounted on *SAS* disks for Merlin5 nodes.
* **Merlin6 computing nodes**: a */scratch* partition of ~1.2TB is available on each computing node. ``/scratch`` is mounted on extremly fast *NVMe Flash* disks for Merlin6 nodes.

#### Shared Scratch

Shared scratch (``/shared-scratch``) is used for creating temporary files/directories needed by running jobs. Temporary files *must be deleted at the end of the job by the user*. 
Remaining files will be deleted by the system if detected. Only use **shared** scratch when you need creating **shared** temporary files, otherwise use **local** by default.

``/shared-scratch`` is only available in the computing nodes, and its current size is 50TB. ``/shared-scratch`` is an independent GPFS filesystem in the new Merlin6 GPFS storagle cluster,
and it can be increased if necessary in the future.

---

## Using the Slurm batch system

Clusters at PSI use the [Slurm Workload Manager](http://slurm.schedmd.com/) as the batch system technology for managing and scheduling jobs. 
Historically, *Merlin4* and *Merlin5* also used Slurm. In the same way, **Merlin6** has been also configured with this batch system.

Slurm has been installed in a **multi-clustered** configuration, allowing to integrate multiple clusters in the same batch system.

For understanding the Slurm configuration setup in the cluster, sometimes may be useful to check the following files:

* ``/etc/slurm/slurm.conf`` - can be found in the login nodes and computing nodes.
* ``/etc/slurm/cgroup.conf`` - can be found in the computing nodes, is also propagated to login nodes for user read access.
* ``/etc/slurm/gres.conf`` - can be found in the GPU nodes, is also propgated to login nodes and computing nodes for user read access.

The previous configuration files which can be found in the login nodes, correspond exclusively to the **merlin6** cluster configuration files. 
Configuration files for the old **merlin5** cluster must be checked directly on any of the **merlin5** computing nodes: these are not propagated
to the **merlin6** login nodes.

### About Merlin5 & Merlin6

The new Slurm cluster is called **merlin6**. However, the old Slurm *merlin* cluster will be kept for some time, and it has been renamed to **merlin5**.
It will allow to keep running jobs in the old computing nodes until users have fully migrated their codes to the new cluster.

From July 2019, **merlin6** becomes the **default cluster** and any job submitted to Slurm will be submitted to that cluster. Users can keep submitting to
the old *merlin5* computing nodes by using the option ``--cluster=merlin5``. 

In this documentation is only explained the usage of the **merlin6** Slurm cluster. 

### Using Slurm 'merlin6' cluster

Basic usage for the **merlin6** cluster will be detailed here. For advanced usage, please use the following document [LINK TO SLURM ADVANCED CONFIG]()

#### Merlin6 Node definition

The following table show default and maximum resources that can be used per node:

| Nodes                              | Def.#CPUs | Max.#CPUs | Def.Mem/CPU | Max.Mem/CPU | Max.Mem/Node | Max.Swap | Def.#GPUs | Max.#GPUs |
|:---------------------------------- | ---------:| ---------:| -----------:| -----------:| ------------:| --------:| --------- | --------- |
| merlin-c-[001-022,101-122,201-222] | 1 core    | 44 cores  | 8000        | 352000      | 352000       | 10000    | N/A       | N/A       |
| merlin-g-[001]                     | 1 core    | 8 cores   | 8000        | 102498      | 102498       | 10000    | 1         | 2         |
| merlin-g-[002-009]                 | 1 core    | 10 cores  | 8000        | 102498      | 102498       | 10000    | 1         | 4         |

If nothing is specified, by default each core will use up to 8GB of memory. More memory per core can be specified with the ``--mem=<memory>`` option,
and maximum memory allowed is ``Max.Mem/Node``.

In *Merlin6*, memory is considered a Consumable Resource, as well as the CPU.

#### Merlin6 Slurm partitions

Partition can be specified when submitting a job with the ``--partition=<partitionname>`` option. 
The following *partitions* (also known as *queues*) are configured in Slurm:

| Partition   | Default Partition | Default Time | Max Time | Max Nodes | Priority |
|:----------- | ----------------- | ------------ | -------- | --------- | -------- |
| **general** | true              | 1 day        | 1 week   | 50        | low      | 
| **daily**   | false             | 1 day        | 1 day    | 60        | medium   | 
| **hourly**  | false             | 1 hour       | 1 hour   | unlimited | highest  | 

General is the *default*, so when nothing is specified job will be by default assigned to that partition. General can not have more than 50 nodes 
running jobs. For **daily** this limitation is extended to 60 nodes while for **hourly** there are no limits. Shorter jobs have more priority than
longer jobs, hence in general terms would be scheduled before (however, other factors such like user fair share value can affect to this decision).

#### Merlin6 User limits

By default, users can not use more than 528 cores at the same time (Max CPU per user). This limit applies for the **general**  and **daily** partitions. For the **hourly** partition, there is no restriction. 
These limits are softed for the **daily** partition during non working hours and during the weekend as follows:

| Partition   | Mon-Fri 08h-18h | Sun-Thu 18h-0h | From Fri 18h to Sun 8h  | From Sun 8h to Mon 18h |
|:----------- | --------------- | -------------- | ----------------------- | ---------------------- |
| **general** | 528             | 528            | 528                     | 528                    | 
| **daily**   | 528             | 792            | Unlimited               | 792                    | 
| **hourly**  | Unlimited       | Unlimited      | Unlimited               | Unlimited              | 

